Class: Neetob::CLI::MonthlyAudit::Security::Github::DependabotTurnedOn

Inherits:
Base
  • Object
show all
Defined in:
lib/neetob/cli/monthly_audit/security/github/dependabot_turned_on.rb

Constant Summary

Constants inherited from Base

Base::NEETO_APPS_LIST_LINK

Instance Attribute Summary

Attributes inherited from Base

#ui

Instance Method Summary collapse

Methods included from Utils

#camel_case_to_slug, #is_upper?, #symbolize_keys

Constructor Details

#initializeDependabotTurnedOn



11
12
13
# File 'lib/neetob/cli/monthly_audit/security/github/dependabot_turned_on.rb', line 11

def initialize
  super()
end

Instance Method Details

#runObject



15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
# File 'lib/neetob/cli/monthly_audit/security/github/dependabot_turned_on.rb', line 15

def run
  ui.success("### 1.2.1. [Manual] Checking whether dependabot is turned on for the repository")
  ui.info "\n"
  ui.info "#### Please manually check and add Yes/No for all the following checks on the Honeybadger dashboard for the apps listed in the table below:"
  ui.info "- Repository > Settings > Code security > Dependabot alerts are enabled"
  ui.info "- Repository > Settings > Code security > Dependabot security updates are enabled"
  ui.info "- Repository > Settings > Actions > Dependabot on Actions runners is enabled"
  ui.info "- Finally, set Audit Passed as Yes only if all the checks are passed for the app, otherwise set it as No, and add a comment in the Comments column"
  ui.info "\n"

  repo_data = [[
    "Repository",
    "Dependabot alerts enabled",
    "Dependabot security updates enabled",
    "Dependabot on Actions runners",
    "Comments",
    "Audit Passed"
    ]
  ]
  NeetoCompliance::NeetoRepos.products.keys.each do |repo|
    repo_data << [repo, nil, nil, nil, nil]
  end
  ui.print_table(repo_data)
end